pub enum PlatformOrderCommand {
Probe {
nonce: String,
},
Challenge {
request: PlatformOrderChallengeRequest,
self_trade_prevention: PlatformSelfTradePrevention,
},
Prepare {
request: PlatformOrderPrepareRequest,
},
Submit {
request: PlatformOrderSubmitRequest,
},
Status {
request: PlatformOrderStatusRequest,
},
DeadManArm {
timeout_ms: u64,
request: PlatformOrderSubmitRequest,
},
DeadManStatus,
DeadManHeartbeat,
DeadManDisarm,
}Expand description
One command on the persistent order-control connection. Challenge results may contain an effective request that differs from the requested one only by the explicitly selected self-trade prevention transformation.
Variants
Probe
Authenticated non-trading round trip used for latency certification.
Challenge
Prepare
Fields

request: PlatformOrderPrepareRequestSubmit
Fields

request: PlatformOrderSubmitRequestStatus
Fields

request: PlatformOrderStatusRequestDeadManArm
DeadManStatus
DeadManHeartbeat
DeadManDisarm