pub struct ExecutionPrepareResponse {
pub schema_version: u16,
pub contract_version: String,
pub execution_id: String,
pub quote_id: String,
pub market_id: String,
pub side: QuoteSide,
pub amount_in_atoms: String,
pub minimum_output_atoms: String,
pub transaction_base64: String,
pub recent_blockhash: String,
pub last_valid_block_height: u64,
pub expires_at_ms: u64,
}Fields
schema_version: u16contract_version: Stringexecution_id: Stringquote_id: Stringmarket_id: Stringside: QuoteSideamount_in_atoms: Stringminimum_output_atoms: StringThe same signed minimum returned by the challenge. Preparation may fail, but it may never weaken this value.
transaction_base64: StringPartially signed Solana v0 transaction. The session signature slot is deliberately empty and must be filled locally.
recent_blockhash: Stringlast_valid_block_height: u64expires_at_ms: u64Trait Implementations
Sourceimpl Clone for ExecutionPrepareResponse
impl Clone for ExecutionPrepareResponse
Sourcefn clone(&self) -> ExecutionPrepareResponse
fn clone(&self) -> ExecutionPrepareResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionPrepareResponse
impl Debug for ExecutionPrepareResponse
Sourceimpl<'de> Deserialize<'de> for ExecutionPrepareResponse
impl<'de> Deserialize<'de> for ExecutionPrepareResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ExecutionPrepareResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ExecutionPrepareResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionPrepareResponse
Sourceimpl PartialEq for ExecutionPrepareResponse
impl PartialEq for ExecutionPrepareResponse
Sourceimpl Serialize for ExecutionPrepareResponse
impl Serialize for ExecutionPrepareResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ExecutionPrepareResponse