pub struct Market {
pub base: String,
pub quote: String,
pub market_pda: Option<String>,
pub label: String,
pub ready: bool,
pub base_decimals: u8,
pub quote_decimals: u8,
pub quote_path: Option<String>,
}Fields
base: Stringquote: Stringmarket_pda: Option<String>label: Stringready: boolWhether the public Sonar quote operation is enabled for this market. Liquidity remains live state and a quote can still be temporarily unavailable.
base_decimals: u8quote_decimals: u8quote_path: Option<String>Stable product-level operation for a Sonar quote. Its implementation remains opaque.