pub struct PlatformMakerControlPrepareResponse {
pub schema_version: u16,
pub contract_version: String,
pub maker_control_id: String,
pub market_id: String,
pub maker_wallet: String,
pub product: PlatformMakerControlProduct,
pub action: PlatformMakerControlAction,
pub transaction_base64: String,
pub recent_blockhash: String,
pub last_valid_block_height: u64,
pub expires_at_ms: u64,
}Fields
schema_version: u16contract_version: Stringmaker_control_id: Stringmarket_id: Stringmaker_wallet: Stringproduct: PlatformMakerControlProductaction: PlatformMakerControlActiontransaction_base64: StringUnsigned Solana transaction in the format negotiated by the prepare endpoint. The maker verifies the exact instruction and fills its only signature slot externally.
recent_blockhash: Stringlast_valid_block_height: u64expires_at_ms: u64Trait Implementations
Sourceimpl Clone for PlatformMakerControlPrepareResponse
impl Clone for PlatformMakerControlPrepareResponse
Sourcefn clone(&self) -> PlatformMakerControlPrepareResponse
fn clone(&self) -> PlatformMakerControlPrepareResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PlatformMakerControlPrepareResponse
impl<'de> Deserialize<'de> for PlatformMakerControlPrepareResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PlatformMakerControlPrepareResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PlatformMakerControlPrepareResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PlatformMakerControlPrepareResponse
Sourceimpl Serialize for PlatformMakerControlPrepareResponse
impl Serialize for PlatformMakerControlPrepareResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for PlatformMakerControlPrepareResponse