PlatformMakerQuickstartRequest

Struct PlatformMakerQuickstartRequest 

pub struct PlatformMakerQuickstartRequest {
    pub market: String,
    pub product: PlatformMakerControlProduct,
    pub spread_bps: u16,
    pub size: String,
    pub duration: Option<String>,
    pub levels: Option<u8>,
    pub level_step_bps: Option<u16>,
    pub side: PlatformMakerQuickstartSide,
    pub async_only: bool,
}
Human-facing maker configuration. spread_bps is the distance from the Strata mark to the first quote on each side. size is an exact decimal base amount, optionally suffixed by its symbol (for example 0.01 SOL).

Fields

market: Stringproduct: PlatformMakerControlProductspread_bps: u16size: Stringduration: Option<String>

None means ten minutes; otherwise 30s, 10m, 2h, or 1d.

levels: Option<u8>

None means three levels.

level_step_bps: Option<u16>

None means the same value as spread_bps.

side: PlatformMakerQuickstartSideasync_only: bool