pub struct PlatformMakerReputationResponse {Show 32 fields
pub schema_version: u16,
pub contract_version: String,
pub market_id: String,
pub maker_id: String,
pub wallet_address: String,
pub active: bool,
pub tier: PlatformMakerReputationTier,
pub reputation_score: u16,
pub total_quote_requests: String,
pub successful_fills: String,
pub missed_quote_requests: String,
pub fill_rate_bps: u16,
pub consecutive_misses: u16,
pub lifetime_filled_quote_atoms: String,
pub distinct_counterparties: u16,
pub recent_average_latency_ms: u16,
pub configured_minimum_spread_bps: u16,
pub weighted_average_spread_bps: u16,
pub stake_atoms: String,
pub epoch_start_stake_atoms: String,
pub epoch_slashed_atoms: String,
pub epoch_slashed_bps: u16,
pub lifetime_auto_slashed_atoms: String,
pub registered_slot: String,
pub last_active_slot: String,
pub last_settled_slot: String,
pub revoked_at_slot: Option<String>,
pub tenure_slots: String,
pub signed_quote_stream_eligible: bool,
pub minimum_quote_interval_ms: Option<u16>,
pub tier_progress: PlatformMakerTierProgress,
pub server_time_ms: u64,
}Expand description
Authenticated, privacy-preserving reliability and participation record for the requesting maker. All potentially large counters and atomic quantities are decimal strings so JavaScript agents never lose integer precision.
Fields
schema_version: u16contract_version: Stringmarket_id: Stringmaker_id: Stringwallet_address: Stringactive: booltier: PlatformMakerReputationTierreputation_score: u16total_quote_requests: Stringsuccessful_fills: Stringmissed_quote_requests: Stringfill_rate_bps: u16consecutive_misses: u16lifetime_filled_quote_atoms: Stringdistinct_counterparties: u16recent_average_latency_ms: u16configured_minimum_spread_bps: u16weighted_average_spread_bps: u16stake_atoms: Stringepoch_start_stake_atoms: Stringepoch_slashed_atoms: Stringepoch_slashed_bps: u16lifetime_auto_slashed_atoms: Stringregistered_slot: Stringlast_active_slot: Stringlast_settled_slot: Stringrevoked_at_slot: Option<String>tenure_slots: Stringsigned_quote_stream_eligible: boolminimum_quote_interval_ms: Option<u16>tier_progress: PlatformMakerTierProgressserver_time_ms: u64Trait Implementations
Sourceimpl Clone for PlatformMakerReputationResponse
impl Clone for PlatformMakerReputationResponse
Sourcefn clone(&self) -> PlatformMakerReputationResponse
fn clone(&self) -> PlatformMakerReputationResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PlatformMakerReputationResponse
impl<'de> Deserialize<'de> for PlatformMakerReputationResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PlatformMakerReputationResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PlatformMakerReputationResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PlatformMakerReputationResponse
Sourceimpl Serialize for PlatformMakerReputationResponse
impl Serialize for PlatformMakerReputationResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for PlatformMakerReputationResponse