pub struct StrataClient { /* private fields */ }Implementations
Sourceimpl StrataClient
impl StrataClient
pub fn production() -> Result<Self, SdkError>
pub fn new(base_url: impl AsRef<str>) -> Result<Self, SdkError>
pub fn with_timeout( base_url: impl AsRef<str>, timeout: Duration, ) -> Result<Self, SdkError>
pub async fn capabilities(&self) -> Result<CapabilityCatalog, SdkError>
pub async fn markets(&self) -> Result<MarketsResponse, SdkError>
Sourcepub async fn quote(
&self,
request: QuoteRequest,
) -> Result<QuoteResponse, SdkError>
pub async fn quote( &self, request: QuoteRequest, ) -> Result<QuoteResponse, SdkError>
Request a short-lived Sonar quote by human market label or market ID.
Sourcepub async fn execute_quote<S, V>(
&self,
quote: &QuoteResponse,
owner_wallet: &str,
account_sequence: u64,
signer: &S,
verifier: &V,
idempotency_key: Option<&str>,
) -> Result<ExecutionSubmitResponse, SdkError>
pub async fn execute_quote<S, V>( &self, quote: &QuoteResponse, owner_wallet: &str, account_sequence: u64, signer: &S, verifier: &V, idempotency_key: Option<&str>, ) -> Result<ExecutionSubmitResponse, SdkError>
Execute one short-lived Sonar quote without giving the SDK custody of a session private key. The transaction verifier always runs before the session adapter is allowed to sign.